==> linkv_rtc-0.0.1.tar.gz: android/src/main/java/com/fusionv/linkv/FlutterSurfaceView.java <==
package com.fusionv.linkv;
import android.content.Context;
import android.graphics.Color;
import android.util.Log;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;

import com.linkv.rtc.LVRTCEngine;
import com.linkv.rtc.entity.LVAVConfig;
import com.linkv.rtc.render.LVDisplayView;

import org.w3c.dom.Text;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.platform.PlatformView;

public class FlutterSurfaceView implements PlatformView {
    private FrameLayout frameLayout;

    FlutterSurfaceView(Context context, Map creationParams, int id) {

//        LVRTCEngine engine = LVRTCEngine.getInstance(context);
        LVRTCEngine engine = LVRTCEnginePlugin.mRtcEngine;
        String uid = (String) creationParams.get("uid");
        boolean isMaster = (boolean) creationParams.get("isMaster");

        LVDisplayView displayView = new LVDisplayView();
        displayView.setUid(uid);
        displayView.isLocalPreviewView(isMaster);
        displayView.isZOrderMediaOverlay(isMaster);
        frameLayout = new FrameLayout(context);
        frameLayout.setLayoutParams(new FrameLayout.LayoutParams(RelativeLayout.LayoutParams.MATCH_PARENT, RelativeLayout.LayoutParams.MATCH_PARENT));
        displayView.setLayoutContainer(frameLayout);
        engine.addDisplayView(context, displayView);

        if (isMaster) {
            engine.startCapture();
        }
    }

    @Override
    public View getView() {
        return  frameLayout;
    }

    @Override
    public void dispose() {
        Log.d("Wing", "dispose");
    }

    @Override
    public void onFlutterViewAttached(@NonNull View flutterView) {
        Log.d("Wing", "onFlutterViewAttached");
    }

    @Override
    public void onFlutterViewDetached() {
        Log.d("Wing", "onFlutterViewDetached");
    }
}

==> linkv_rtc-0.0.9.tar.gz: android/src/main/java/com/fusionv/linkv/FlutterSurfaceView.java <==
package com.fusionv.linkv;
import android.content.Context;
import android.graphics.Color;
import android.util.Log;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.RelativeLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;

import com.linkv.rtc.LVRTCEngine;
import com.linkv.rtc.entity.LVAVConfig;
import com.linkv.rtc.render.LVDisplayView;

import org.w3c.dom.Text;

import java.util.HashMap;
import java.util.Map;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.platform.PlatformView;

public class FlutterSurfaceView implements PlatformView {
    private FrameLayout frameLayout;
    LVDisplayView displayView;

    FlutterSurfaceView(Context context, Map creationParams, int id) {

        LVRTCEngine engine = LVRTCEnginePlugin.mRtcEngine;
        String uid = (String) creationParams.get("uid");
        boolean isMaster = (boolean) creationParams.get("isMaster");

        displayView = new LVDisplayView();
        displayView.setUid(uid);
        displayView.isLocalPreviewView(isMaster);
        displayView.isZOrderMediaOverlay(isMaster);
        frameLayout = new FrameLayout(context);
        frameLayout.setLayoutParams(new FrameLayout.LayoutParams(RelativeLayout.LayoutParams.MATCH_PARENT, RelativeLayout.LayoutParams.MATCH_PARENT));
        displayView.setLayoutContainer(frameLayout);
        engine.addDisplayView(context, displayView);

        if (isMaster) {
            engine.startCapture();
        }
    }

    @Override
    public View getView() {
        return  frameLayout;
    }

    @Override
    public void dispose() {
        Log.d("Wing", "dispose");

        if (displayView != null) {
            LVRTCEnginePlugin.mRtcEngine.removeDisplayView(displayView);
        }
    }

    @Override
    public void onFlutterViewAttached(@NonNull View flutterView) {
        Log.d("Wing", "onFlutterViewAttached");
    }

    @Override
    public void onFlutterViewDetached() {
        Log.d("Wing", "onFlutterViewDetached");
    }
}
